@@ -6,23 +6,23 @@
 
 /*
 Author:
-	Artur Araujo <artur.stat@gmail.com>
+  Artur Araujo <artur.stat@gmail.com>
 
 Description:
-	Computes quantiles of a given vector.
+  Computes quantiles of a given vector.
 
 Parameters:
-	len[in]			pointer to length of V.
-	V[inout]		pointer to V first element.
-	n[in]			pointer to length of P and Q.
-	P[in]			pointer to P first element.
-	Q[out]			pointer to Q first element.
+  len[in]           pointer to length of V.
+  V[inout]          pointer to V first element.
+  n[in]             pointer to length of P and Q.
+  P[in]             pointer to P first element.
+  Q[out]            pointer to Q first element.
 
 Return value:
-	This function doesn't return a value.
+  This function doesn't return a value.
 
 Remarks:
-	Vector V is sorted inside of this function.
+  Vector V is sorted inside of this function.
 */
 
 void quantile_d(
@@ -36,10 +36,12 @@ void quantile_d(
 	int j, k;
 	double g;
 	sort_d(V, *len, FALSE, FALSE); // sort vector
-	for (k = 0; k < *len; k++) if ( !ISNAN(V[k]) ) break; // find first NaN or NA
+	for (k = 0; k < *len; k++) {
+	  if ( !R_IsNA(V[k]) && !R_IsNaN(V[k]) ) break; // find first NA or NaN
+	}
 	for (i = 0; i < *n; i++) {
 		g = P[i]*(*len-k-1);
-		j = g;
+		j = (int)g;
 		if (j == *len-k-1) Q[i] = V[*len-1]; // compute quantile
 		else {
 			g -= j;
